@@ -3,21 +3,16 @@ Contains Geschaeftspartner class
 and corresponding marshmallow schema for de-/serialization
 """
 # pylint: disable=too-many-instance-attributes, too-few-public-methods
-from typing import List, Optional, Type
+from typing import List, Optional
 
-import attrs
-from marshmallow import fields
-from marshmallow_enum import EnumField  # type:ignore[import]
-
-from bo4e.bo.geschaeftsobjekt import Geschaeftsobjekt, GeschaeftsobjektSchema
-from bo4e.com.adresse import Adresse, AdresseSchema
+from bo4e.bo.geschaeftsobjekt import Geschaeftsobjekt
+from bo4e.com.adresse import Adresse
 from bo4e.enum.anrede import Anrede
 from bo4e.enum.botyp import BoTyp
 from bo4e.enum.geschaeftspartnerrolle import Geschaeftspartnerrolle
 from bo4e.enum.kontaktart import Kontaktart
 
 
-@attrs.define(auto_attribs=True, kw_only=True)
 class Geschaeftspartner(Geschaeftsobjekt):
     """
     Mit diesem Objekt können Geschäftspartner übertragen werden.
@@ -25,13 +20,17 @@ class Geschaeftspartner(Geschaeftsobjekt):
     Hinweis: Marktteilnehmer haben ein eigenes BO, welches sich von diesem BO ableitet.
     Hier sollte daher keine Zuordnung zu Marktrollen erfolgen.
 
+    .. raw:: html
+
+        <object data="../_static/images/bo4e/bo/Geschaeftspartner.svg" type="image/svg+xml"></object>
+
     .. HINT::
-        `Geschaeftspartner JSON Schema <https://json-schema.app/view/%23?url=https://raw.githubusercontent.com/Hochfrequenz/BO4E-python/main/json_schemas/bo/GeschaeftspartnerSchema.json>`_
+        `Geschaeftspartner JSON Schema <https://json-schema.app/view/%23?url=https://raw.githubusercontent.com/Hochfrequenz/BO4E-python/main/json_schemas/bo/Geschaeftspartner.json>`_
 
     """
 
     # required attributes
-    bo_typ: BoTyp = attrs.field(default=BoTyp.GESCHAEFTSPARTNER)
+    bo_typ: BoTyp = BoTyp.GESCHAEFTSPARTNER
     name1: str
     """
     Erster Teil des Namens.
@@ -47,66 +46,38 @@ class Geschaeftspartner(Geschaeftsobjekt):
     oder eine Privatperson handelt. (gewerbeKennzeichnung = false)
     """
     #: Rollen, die die Geschäftspartner inne haben (z.B. Interessent, Kunde)
-    geschaeftspartnerrolle: List[Geschaeftspartnerrolle] = attrs.field(validator=attrs.validators.instance_of(List))
+    geschaeftspartnerrolle: List[Geschaeftspartnerrolle]
     # todo: rename to plural
 
     # optional attributes
     #: Die Anrede für den GePa, Z.B. "Herr"
-    anrede: Anrede = attrs.field(default=None)
-    name2: Optional[str] = attrs.field(default=None)
+    anrede: Optional[Anrede] = None
+    name2: Optional[str] = None
     """
     Zweiter Teil des Namens.
     Hier kann der eine Erweiterung zum Firmennamen oder bei Privatpersonen beispielsweise der Vorname dagestellt werden.
     Beispiele: Bereich Süd oder Nina
     """
 
-    name3: Optional[str] = attrs.field(default=None)
+    name3: Optional[str] = None
     """
     Dritter Teil des Namens.
     Hier können weitere Ergänzungen zum Firmennamen oder bei Privatpersonen Zusätze zum Namen dagestellt werden.
     Beispiele: und Afrika oder Sängerin
     """
     #: Handelsregisternummer des Geschäftspartners
-    hrnummer: Optional[str] = attrs.field(default=None)
+    hrnummer: Optional[str] = None
     #: Amtsgericht bzw Handelsregistergericht, das die Handelsregisternummer herausgegeben hat
-    amtsgericht: Optional[str] = attrs.field(default=None)
+    amtsgericht: Optional[str] = None
     #: Bevorzugte Kontaktwege des Geschäftspartners
-    kontaktweg: List[Kontaktart] = attrs.field(default=[])
+    kontaktweg: List[Kontaktart] = []
     #: Die Steuer-ID des Geschäftspartners; Beispiel: "DE 813281825"
-    umsatzsteuer_id: Optional[str] = attrs.field(default=None)
+    umsatzsteuer_id: Optional[str] = None
     #: Die Gläubiger-ID welche im Zahlungsverkehr verwendet wird; Z.B. "DE 47116789"
-    glaeubiger_id: Optional[str] = attrs.field(default=None)
+    glaeubiger_id: Optional[str] = None
     #: E-Mail-Adresse des Ansprechpartners. Z.B. "info@hochfrequenz.de"
-    e_mail_adresse: Optional[str] = attrs.field(default=None)
+    e_mail_adresse: Optional[str] = None
     #: Internetseite des Marktpartners
-    website: Optional[str] = attrs.field(default=None)
+    website: Optional[str] = None
     #: Adressen der Geschäftspartner, an denen sich der Hauptsitz befindet
-    partneradresse: Adresse = attrs.field(default=None)  # todo: is it plural or not? the docs are bad
-
-
-class GeschaeftspartnerSchema(GeschaeftsobjektSchema):
-    """
-    Schema for de-/serialization of Geschaeftspartner.
-    """
-
-    # class_name is needed to use the correct schema for deserialisation.
-    # see function `deserialize` in geschaeftsobjekt.py
-    class_name: Type[Geschaeftspartner] = Geschaeftspartner
-
-    # required attributes
-    name1 = fields.Str()
-    gewerbekennzeichnung = fields.Bool()
-    geschaeftspartnerrolle = fields.List(EnumField(Geschaeftspartnerrolle))
-
-    # optional attributes
-    anrede = EnumField(Anrede, load_default=None)
-    name2 = fields.Str(load_default=None)
-    name3 = fields.Str(load_default=None)
-    hrnummer = fields.Str(load_default=None)
-    amtsgericht = fields.Str(load_default=None)
-    kontaktweg = fields.List(EnumField(Kontaktart), load_default=None)
-    umsatzsteuer_id = fields.Str(load_default=None)
-    glaeubiger_id = fields.Str(load_default=None, data_key="glauebigerId")
-    e_mail_adresse = fields.Str(load_default=None)
-    website = fields.Str(load_default=None)
-    partneradresse = fields.Nested(AdresseSchema, load_default=None)
+    partneradresse: Optional[Adresse] = None  # todo: is it plural or not? the docs are bad
