@@ -1,14 +1,18 @@
-import json
+from typing import Dict, Optional
 
 import pytest  # type:ignore[import]
+from py._path.local import LocalPath  # type: ignore[import]
+from pydantic import ValidationError
 
-from bo4e.com.adresse import Adresse, AdresseSchema
+from bo4e.com.adresse import Adresse
 from bo4e.enum.landescode import Landescode
 
+# import pydantic
+
 # can be imported by other tests
 example_adresse = Adresse(
     ort="Grünwald",
-    landescode=Landescode.DE,  # type:ignore[attr-defined]
+    landescode=Landescode.DE,  # type: ignore[attr-defined]
     hausnummer="27A",
     strasse="Nördliche Münchner Straße",
     postleitzahl="82031",
@@ -16,41 +20,33 @@ example_adresse = Adresse(
 
 
 class TestAddress:
-    def test_serialization_strasse(self):
+    def test_serialization_strasse(self) -> None:
         """
         Test serialization with strasse und hausnummer
         and default value of landescode
         """
-        with open(
+
+        address_test_data = Adresse.parse_file(
             "./tests/test_data/test_data_adresse/test_data_adresse_only_required_fields.json",
             encoding="utf-8",
-        ) as json_file:
-            address_test_data = json.load(json_file)
-
-        a = Adresse(
-            postleitzahl=address_test_data["postleitzahl"],
-            ort=address_test_data["ort"],
-            strasse=address_test_data["strasse"],
-            hausnummer=address_test_data["hausnummer"],
         )
 
-        schema = AdresseSchema()
-        address_dict = schema.dump(a)
+        address_dict = address_test_data.json(by_alias=True, ensure_ascii=False)
 
-        assert address_dict["strasse"] == "Nördliche Münchner Straße"
-        assert address_dict["hausnummer"] == "27A"
-        assert address_dict["postleitzahl"] == "82031"
-        assert address_dict["landescode"] == "DE"
+        assert "Nördliche Münchner Straße" in address_dict
+        assert "27A" in address_dict
+        assert "82031" in address_dict
+        assert "DE" in address_dict
 
-        deserialized_address = schema.load(address_dict)
+        deserialized_address = Adresse.parse_raw(address_dict)
 
         assert isinstance(deserialized_address, Adresse)
         assert deserialized_address.strasse == "Nördliche Münchner Straße"
         assert deserialized_address.hausnummer == "27A"
         assert deserialized_address.postleitzahl == "82031"
-        assert deserialized_address.landescode == Landescode.DE
+        assert deserialized_address.landescode == Landescode.DE  # type: ignore[attr-defined]
 
-    def test_serialization_only_postfach(self):
+    def test_serialization_only_postfach(self) -> None:
         """Test serialization with postfach"""
         address_test_data = {
             "postleitzahl": "82031",
@@ -64,21 +60,20 @@ class TestAddress:
             postfach=address_test_data["postfach"],
         )
 
-        schema = AdresseSchema()
-        address_json = schema.dumps(a, ensure_ascii=False)
+        address_json = a.json(by_alias=True, ensure_ascii=False)
 
         assert "10 64 38" in address_json
         assert "82031" in address_json
         assert "DE" in address_json
 
-        deserialized_address = schema.loads(address_json)
+        deserialized_address = Adresse.parse_raw(address_json)
 
         assert isinstance(deserialized_address, Adresse)
         assert deserialized_address.postfach == "10 64 38"
         assert deserialized_address.postleitzahl == "82031"
-        assert deserialized_address.landescode == Landescode.DE
+        assert deserialized_address.landescode == Landescode.DE  # type: ignore[attr-defined]
 
-    def test_serialization_only_required_fields(self):
+    def test_serialization_only_required_fields(self) -> None:
         """Test serialization with just postleitzahl und ort"""
         address_test_data = {
             "postleitzahl": "82031",
@@ -90,64 +85,48 @@ class TestAddress:
             ort=address_test_data["ort"],
         )
 
-        schema = AdresseSchema()
-        address_json = schema.dumps(a, ensure_ascii=False)
+        address_json = a.json(by_alias=True, ensure_ascii=False)
 
         assert "Grünwald" in address_json
         assert "82031" in address_json
 
-        deserialized_address = schema.loads(address_json)
+        deserialized_address = Adresse.parse_raw(address_json)
 
         assert isinstance(deserialized_address, Adresse)
         assert deserialized_address.ort == "Grünwald"
         assert deserialized_address.postleitzahl == "82031"
 
-    def test_serialization_only_required_fields_landescode_AT(self):
-        with open(
+    def test_serialization_only_required_fields_landescode_AT(self) -> None:
+
+        address_test_data = Adresse.parse_file(
             "./tests/test_data/test_data_adresse/test_data_adresse_only_required_fields.json",
             encoding="utf-8",
-        ) as json_file:
-            address_test_data = json.load(json_file)
-
-        a = Adresse(
-            postleitzahl=address_test_data["postleitzahl"],
-            ort=address_test_data["ort"],
-            strasse=address_test_data["strasse"],
-            hausnummer=address_test_data["hausnummer"],
-            landescode=Landescode.AT,
         )
+        address_test_data.landescode = Landescode.AT  # type: ignore[attr-defined]
 
-        schema = AdresseSchema()
-        address_json = schema.dumps(a, ensure_ascii=False)
-        deserialized_address = schema.loads(address_json)
+        address_json = address_test_data.json(by_alias=True, ensure_ascii=False)
+        deserialized_address = Adresse.parse_raw(address_json)
 
-        assert deserialized_address.landescode == Landescode.AT
+        assert deserialized_address.landescode == Landescode.AT  # type: ignore[attr-defined]
 
-    def test_deserialization(self):
+    def test_deserialization(self) -> None:
         json_string = r"""{"strasse":"Getreidegasse",
                  "hausnummer":"9",
                  "ort":"Salzburg",
                  "postleitzahl":"5020",
                  "landescode":"AT"}"""
 
-        schema = AdresseSchema()
-        a: Adresse = schema.loads(json_string)
-        assert a.landescode is Landescode.AT
+        a: Adresse = Adresse.parse_raw(json_string)
+        assert a.landescode is Landescode.AT  # type: ignore[attr-defined]
 
     @pytest.mark.datafiles("./tests/test_data/test_data_adresse/test_data_adresse_missing_plz.json")
-    def test_missing_required_attribute(self, datafiles):
+    def test_missing_required_attribute(self, datafiles: LocalPath) -> None:
         """
         Test for getting an error message if a required attribute is missing
         """
-        with open(datafiles / "test_data_adresse_missing_plz.json", encoding="utf-8") as json_file:
-            address_test_data = json.load(json_file)
 
-        with pytest.raises(TypeError) as excinfo:
-            _ = Adresse(
-                ort=address_test_data["ort"],
-                strasse=address_test_data["strasse"],
-                hausnummer=address_test_data["hausnummer"],
-            )
+        with pytest.raises(ValidationError) as excinfo:
+            _ = Adresse.parse_file(datafiles / "test_data_adresse_missing_plz.json", encoding="utf-8")
 
         assert "postleitzahl" in str(excinfo.value)
 
@@ -162,7 +141,7 @@ class TestAddress:
                     "hausnummer": None,
                     "postfach": None,
                 },
-                "Missing hausnummer",
+                'You have to define either "strasse" and "hausnummer" or "postfach".',
                 id="Missing hausnummer",
             ),
             pytest.param(
@@ -173,7 +152,7 @@ class TestAddress:
                     "hausnummer": "27A",
                     "postfach": None,
                 },
-                "Missing strasse",
+                'You have to define either "strasse" and "hausnummer" or "postfach".',
                 id="Missing strasse",
             ),
             pytest.param(
@@ -184,7 +163,7 @@ class TestAddress:
                     "hausnummer": "27A",
                     "postfach": "10 64 38",
                 },
-                "hausnummer OR postfach",
+                'You have to define either "strasse" and "hausnummer" or "postfach".',
                 id="Strasse, hausnummer and postfach",
             ),
             pytest.param(
@@ -195,32 +174,32 @@ class TestAddress:
                     "hausnummer": "27A",
                     "postfach": "10 64 38",
                 },
-                "hausnummer OR postfach",
+                'You have to define either "strasse" and "hausnummer" or "postfach".',
                 id="Postfach and hausnummer",
             ),
         ],
     )
-    def test_strasse_xor_postfach(self, address_test_data, expected):
-        with pytest.raises(ValueError) as excinfo:
+    def test_strasse_xor_postfach(self, address_test_data: Dict[str, Optional[str]], expected: str) -> None:
+        with pytest.raises(ValidationError) as excinfo:
             _ = Adresse(
-                postleitzahl=address_test_data["postleitzahl"],
-                ort=address_test_data["ort"],
+                postleitzahl=address_test_data["postleitzahl"],  # type: ignore[arg-type]
+                ort=address_test_data["ort"],  # type: ignore[arg-type]
                 strasse=address_test_data["strasse"],
                 hausnummer=address_test_data["hausnummer"],
                 postfach=address_test_data["postfach"],
             )
         assert expected in str(excinfo.value)
 
-    def test_serialization_of_non_german_address(self):
+    def test_serialization_of_non_german_address(self) -> None:
         """
         Minimal working example
         :return:
         """
         a = Adresse(
-            postleitzahl="6413", ort="Wildermieming", strasse="Gerhardhof", hausnummer="1", landescode=Landescode.AT
+            postleitzahl="6413", ort="Wildermieming", strasse="Gerhardhof", hausnummer="1", landescode=Landescode.AT  # type: ignore[attr-defined]
         )
-        assert a.landescode == Landescode.AT
-        serialized_address = AdresseSchema().dumps(a)
+        assert a.landescode == Landescode.AT  # type: ignore[attr-defined]
+        serialized_address = a.json(by_alias=True, ensure_ascii=False)
         assert '"AT"' in serialized_address
-        deserialized_address = AdresseSchema().loads(serialized_address)
-        assert deserialized_address.landescode == Landescode.AT
+        deserialized_address = Adresse.parse_raw(serialized_address)
+        assert deserialized_address.landescode == Landescode.AT  # type: ignore[attr-defined]
