@@ -1,12 +1,16 @@
 from decimal import Decimal
+from typing import Any, Dict
 
 import pytest  # type:ignore[import]
+from pydantic import ValidationError
 
-from bo4e.com.ausschreibungsdetail import Ausschreibungsdetail, AusschreibungsdetailSchema
+from bo4e.com.ausschreibungsdetail import Ausschreibungsdetail
 from bo4e.com.menge import Menge
+from bo4e.enum.landescode import Landescode
 from bo4e.enum.mengeneinheit import Mengeneinheit
 from bo4e.enum.netzebene import Netzebene
 from bo4e.enum.zaehlertyp import Zaehlertyp
+from bo4e.enum.zeiteinheit import Zeiteinheit
 from tests.serialization_helper import assert_serialization_roundtrip  # type:ignore[import]
 from tests.test_adresse import example_adresse  # type:ignore[import]
 from tests.test_menge import example_menge  # type:ignore[import]
@@ -26,15 +30,15 @@ example_ausschreibungsdetail_dict = {
     "kunde": None,
     "lokationsbezeichnung": None,
     "lieferzeitraum": {
-        "dauer": "5",
+        "dauer": Decimal("5"),
         "startdatum": None,
         "endzeitpunkt": None,
         "enddatum": None,
-        "einheit": "TAG",
+        "einheit": Zeiteinheit.TAG,
         "startzeitpunkt": None,
     },
     "lokationsadresse": {
-        "landescode": "DE",
+        "landescode": Landescode.DE,  # type: ignore[attr-defined]
         "hausnummer": "27A",
         "strasse": "Nördliche Münchner Straße",
         "postleitzahl": "82031",
@@ -44,7 +48,7 @@ example_ausschreibungsdetail_dict = {
         "coErgaenzung": None,
     },
     "rechnungsadresse": {
-        "landescode": "DE",
+        "landescode": Landescode.DE,  # type: ignore[attr-defined]
         "hausnummer": "27A",
         "strasse": "Nördliche Münchner Straße",
         "postleitzahl": "82031",
@@ -54,9 +58,9 @@ example_ausschreibungsdetail_dict = {
         "coErgaenzung": None,
     },
     "netzbetreiber": None,
-    "netzebeneLieferung": "MSP",
+    "netzebeneLieferung": Netzebene.MSP,
     "prognoseArbeitLieferzeitraum": None,
-    "netzebeneMessung": "NSP",
+    "netzebeneMessung": Netzebene.NSP,
     "prognoseLeistung": None,
     "lastgangVorhanden": None,
     "prognoseJahresarbeit": None,
@@ -91,12 +95,12 @@ class TestAusschreibungsdetail:
                     "lieferzeitraum": {
                         "enddatum": None,
                         "startdatum": None,
-                        "einheit": "TAG",
+                        "einheit": Zeiteinheit.TAG,
                         "endzeitpunkt": None,
-                        "dauer": "5",
+                        "dauer": Decimal("5"),
                         "startzeitpunkt": None,
                     },
-                    "zaehlertechnik": "LEISTUNGSZAEHLER",
+                    "zaehlertechnik": Zaehlertyp.LEISTUNGSZAEHLER,
                     "kunde": "Dei Mudder ihr Kunde",
                     "lokationsbezeichnung": "Zentraler Einkauf, Hamburg",
                     "lokationsadresse": {
@@ -104,7 +108,7 @@ class TestAusschreibungsdetail:
                         "adresszusatz": None,
                         "postfach": None,
                         "postleitzahl": "82031",
-                        "landescode": "DE",
+                        "landescode": Landescode.DE,  # type: ignore[attr-defined]
                         "ort": "Grünwald",
                         "strasse": "Nördliche Münchner Straße",
                         "coErgaenzung": None,
@@ -114,33 +118,35 @@ class TestAusschreibungsdetail:
                         "adresszusatz": None,
                         "postfach": None,
                         "postleitzahl": "82031",
-                        "landescode": "DE",
+                        "landescode": Landescode.DE,  # type: ignore[attr-defined]
                         "ort": "Grünwald",
                         "strasse": "Nördliche Münchner Straße",
                         "coErgaenzung": None,
                     },
                     "zaehlernummer": "1YSK4234092304",
-                    "prognoseJahresarbeit": {"wert": "2500", "einheit": "KWH"},
-                    "netzebeneLieferung": "MSP",
+                    "prognoseJahresarbeit": {"wert": Decimal("2500"), "einheit": Mengeneinheit.KWH},
+                    "netzebeneLieferung": Netzebene.MSP,
                     "lokationsId": "56789012345",
-                    "prognoseLeistung": {"wert": "40", "einheit": "KW"},
+                    "prognoseLeistung": {"wert": Decimal("40"), "einheit": Mengeneinheit.KW},
                     "lastgangVorhanden": True,
-                    "netzebeneMessung": "NSP",
-                    "prognoseArbeitLieferzeitraum": {"wert": "2500", "einheit": "KWH"},
+                    "netzebeneMessung": Netzebene.NSP,
+                    "prognoseArbeitLieferzeitraum": {"wert": Decimal("2500"), "einheit": Mengeneinheit.KWH},
                 },
             ),
             pytest.param(example_ausschreibungsdetail, example_ausschreibungsdetail_dict),
         ],
     )
-    def test_serialization_roundtrip(self, ausschreibungsdetail: Ausschreibungsdetail, expected_json_dict: dict):
+    def test_serialization_roundtrip(
+        self, ausschreibungsdetail: Ausschreibungsdetail, expected_json_dict: Dict[str, Any]
+    ) -> None:
         """
         Test de-/serialisation of Ausschreibungsdetail
         """
-        assert_serialization_roundtrip(ausschreibungsdetail, AusschreibungsdetailSchema(), expected_json_dict)
+        assert_serialization_roundtrip(ausschreibungsdetail, expected_json_dict)
 
-    def test_missing_required_attribute(self):
-        with pytest.raises(TypeError) as excinfo:
-            _ = Ausschreibungsdetail()
+    def test_missing_required_attribute(self) -> None:
+        with pytest.raises(ValidationError) as excinfo:
+            _ = Ausschreibungsdetail()  # type: ignore[call-arg]
 
-        assert "missing 5 required" in str(excinfo.value)
+        assert "5 validation errors" in str(excinfo.value)
         # 'lokations_id', 'netzebene_lieferung', 'netzebene_messung', 'lokationsadresse', and 'lieferzeitraum'
