@@ -1,6 +1,7 @@
 import pytest  # type:ignore[import]
+from pydantic import ValidationError
 
-from bo4e.bo.energiemenge import Energiemenge, EnergiemengeSchema
+from bo4e.bo.energiemenge import Energiemenge
 from bo4e.enum.lokationstyp import Lokationstyp
 from tests.serialization_helper import assert_serialization_roundtrip  # type:ignore[import]
 from tests.test_verbrauch import example_verbrauch  # type:ignore[import]
@@ -19,11 +20,11 @@ class TestEnergiemenge:
             ),
         ],
     )
-    def test_serialization_roundtrip(self, energiemenge: Energiemenge):
-        assert_serialization_roundtrip(energiemenge, EnergiemengeSchema())
+    def test_serialization_roundtrip(self, energiemenge: Energiemenge) -> None:
+        assert_serialization_roundtrip(energiemenge)
 
-    def test_missing_required_attribute(self):
-        with pytest.raises(TypeError) as excinfo:
-            _ = Energiemenge()
+    def test_missing_required_attribute(self) -> None:
+        with pytest.raises(ValidationError) as excinfo:
+            _ = Energiemenge()  # type: ignore[call-arg]
 
-        assert "missing 3 required" in str(excinfo.value)
+        assert "3 validation errors" in str(excinfo.value)
