@@ -1,9 +1,11 @@
 from decimal import Decimal
+from typing import Any, Dict
 
 import pytest  # type:ignore[import]
+from pydantic import ValidationError
 
 from bo4e.com.energieherkunft import Energieherkunft
-from bo4e.com.energiemix import Energiemix, EnergiemixSchema
+from bo4e.com.energiemix import Energiemix
 from bo4e.enum.erzeugungsart import Erzeugungsart
 from bo4e.enum.oekolabel import Oekolabel
 from bo4e.enum.oekozertifikat import Oekozertifikat
@@ -32,13 +34,13 @@ class TestEnergiemix:
                 example_energiemix,
                 {
                     "energiemixnummer": 2,
-                    "energieart": "STROM",
+                    "energieart": Sparte.STROM,
                     "bezeichnung": "foo",
                     "gueltigkeitsjahr": 2021,
                     "anteil": [
                         {
-                            "erzeugungsart": "BIOGAS",
-                            "anteilProzent": "40",
+                            "erzeugungsart": Erzeugungsart.BIOGAS,
+                            "anteilProzent": Decimal("40"),
                         }
                     ],
                     "oekolabel": [],
@@ -80,23 +82,23 @@ class TestEnergiemix:
                 ),
                 {
                     "energiemixnummer": 2,
-                    "energieart": "STROM",
+                    "energieart": Sparte.STROM,
                     "bezeichnung": "foo",
                     "gueltigkeitsjahr": 2021,
                     "anteil": [
                         {
-                            "erzeugungsart": "BIOGAS",
-                            "anteilProzent": "40",
+                            "erzeugungsart": Erzeugungsart.BIOGAS,
+                            "anteilProzent": Decimal("40"),
                         },
                         {
-                            "erzeugungsart": "GEOTHERMIE",
-                            "anteilProzent": "60",
+                            "erzeugungsart": Erzeugungsart.GEOTHERMIE,
+                            "anteilProzent": Decimal("60"),
                         },
                     ],
                     "oekolabel": ["GASGREEN", "GRUENER_STROM_GOLD"],
                     "bemerkung": "bar",
-                    "co2Emission": "40",
-                    "atommuell": "5",
+                    "co2Emission": Decimal("40"),
+                    "atommuell": Decimal("5"),
                     "website": "foobar.de",
                     "oekozertifikate": ["FRAUNHOFER", "FREIBERG"],
                     "oekoTopTen": True,
@@ -105,20 +107,22 @@ class TestEnergiemix:
             ),
         ],
     )
-    def test_energiemix_serialization_roundtrip(self, energiemix, expected_json_dict):
+    def test_energiemix_serialization_roundtrip(
+        self, energiemix: Energiemix, expected_json_dict: Dict[str, Any]
+    ) -> None:
         """
         Test de-/serialisation of Energiehermix with minimal attributes.
         """
-        assert_serialization_roundtrip(energiemix, EnergiemixSchema(), expected_json_dict)
+        assert_serialization_roundtrip(energiemix, expected_json_dict)
 
-    def test_energiemix_missing_required_attribute(self):
-        with pytest.raises(TypeError) as excinfo:
-            _ = Energiemix()
+    def test_energiemix_missing_required_attribute(self) -> None:
+        with pytest.raises(ValidationError) as excinfo:
+            _ = Energiemix()  # type: ignore[call-arg]
 
-        assert "missing 5 required" in str(excinfo.value)
+        assert "5 validation errors" in str(excinfo.value)
 
-    def test_energiemix_anteil_required(self):
-        with pytest.raises(ValueError) as excinfo:
+    def test_energiemix_anteil_required(self) -> None:
+        with pytest.raises(ValidationError) as excinfo:
             _ = Energiemix(
                 energiemixnummer=2,
                 energieart=Sparte.STROM,
@@ -127,4 +131,5 @@ class TestEnergiemix:
                 anteil=[],
             )
 
-        assert "List anteil must not be empty." in str(excinfo.value)
+        assert "1 validation error" in str(excinfo.value)
+        assert "ensure this value has at least 1 item" in str(excinfo.value)
