@@ -1,6 +1,7 @@
 import pytest  # type:ignore[import]
+from pydantic import ValidationError
 
-from bo4e.bo.fremdkosten import Fremdkosten, FremdkostenSchema
+from bo4e.bo.fremdkosten import Fremdkosten
 from bo4e.com.fremdkostenblock import Fremdkostenblock
 from tests.serialization_helper import assert_serialization_roundtrip  # type:ignore[import]
 from tests.test_betrag import example_betrag  # type:ignore[import]
@@ -20,13 +21,13 @@ class TestFremdkosten:
             ),
         ],
     )
-    def test_serialization_roundtrip(self, fremdkosten: Fremdkosten):
+    def test_serialization_roundtrip(self, fremdkosten: Fremdkosten) -> None:
         """
         Test de-/serialisation
         """
-        assert_serialization_roundtrip(fremdkosten, FremdkostenSchema())
+        assert_serialization_roundtrip(fremdkosten)
 
-    def test_missing_required_attribute(self):
-        with pytest.raises(TypeError) as excinfo:
-            _ = Fremdkosten()
-        assert "missing 1 required" in str(excinfo.value)
+    def test_missing_required_attribute(self) -> None:
+        with pytest.raises(ValidationError) as excinfo:
+            _ = Fremdkosten()  # type: ignore[call-arg]
+        assert "1 validation error" in str(excinfo.value)
