@@ -1,6 +1,8 @@
+from typing import Any, Dict
+
 import pytest  # type:ignore[import]
 
-from bo4e.com.geraet import Geraet, GeraetSchema
+from bo4e.com.geraet import Geraet
 from bo4e.com.geraeteeigenschaften import Geraeteeigenschaften
 from bo4e.enum.geraetemerkmal import Geraetemerkmal
 from bo4e.enum.geraetetyp import Geraetetyp
@@ -22,14 +24,14 @@ class TestGeraet:
                 ),
                 {
                     "geraetenummer": "0815",
-                    "geraeteeigenschaften": {"geraetemerkmal": "GAS_G1000", "geraetetyp": "MULTIPLEXANLAGE"},
+                    "geraeteeigenschaften": {"geraetemerkmal": "GAS_G1000", "geraetetyp": Geraetetyp.MULTIPLEXANLAGE},
                 },
                 id="Maximal attributes",
             ),
         ],
     )
-    def test_serialization_roundtrip(self, geraet: Geraet, expected_json_dict: dict):
+    def test_serialization_roundtrip(self, geraet: Geraet, expected_json_dict: Dict[str, Any]) -> None:
         """
         Test de-/serialisation of Geraet
         """
-        assert_serialization_roundtrip(geraet, GeraetSchema(), expected_json_dict)
+        assert_serialization_roundtrip(geraet, expected_json_dict)
