@@ -1,6 +1,9 @@
-import pytest  # type:ignore[import]
+from typing import Any, Dict
 
-from bo4e.com.geraeteeigenschaften import Geraeteeigenschaften, GeraeteeigenschaftenSchema
+import pytest  # type:ignore[import]
+from pydantic import ValidationError
+
+from bo4e.com.geraeteeigenschaften import Geraeteeigenschaften
 from bo4e.enum.geraetemerkmal import Geraetemerkmal
 from bo4e.enum.geraetetyp import Geraetetyp
 from tests.serialization_helper import assert_serialization_roundtrip  # type:ignore[import]
@@ -16,21 +19,23 @@ class TestGeraeteeigenschaften:
         [
             pytest.param(
                 example_geraeteeigenschaften,
-                {"geraetemerkmal": "GAS_G1000", "geraetetyp": "MULTIPLEXANLAGE"},
+                {"geraetemerkmal": "GAS_G1000", "geraetetyp": Geraetetyp.MULTIPLEXANLAGE},
             ),
         ],
     )
-    def test_serialization_roundtrip(self, geraeteeigenschaften: Geraeteeigenschaften, expected_json_dict: dict):
+    def test_serialization_roundtrip(
+        self, geraeteeigenschaften: Geraeteeigenschaften, expected_json_dict: Dict[str, Any]
+    ) -> None:
         """
         Test de-/serialisation of Geraeteeigenschaften
         """
-        assert_serialization_roundtrip(geraeteeigenschaften, GeraeteeigenschaftenSchema(), expected_json_dict)
+        assert_serialization_roundtrip(geraeteeigenschaften, expected_json_dict)
 
-    def test_missing_required_attribute(self):
-        with pytest.raises(TypeError) as excinfo:
-            _ = Geraeteeigenschaften()
+    def test_missing_required_attribute(self) -> None:
+        with pytest.raises(ValidationError) as excinfo:
+            _ = Geraeteeigenschaften()  # type: ignore[call-arg]
 
-        assert "missing 1 required" in str(excinfo.value)
+        assert "1 validation error" in str(excinfo.value)
 
     @pytest.mark.parametrize(
         "not_a_geraetetyp",
@@ -39,8 +44,9 @@ class TestGeraeteeigenschaften:
             pytest.param("foo"),  # not a geraetetyp
         ],
     )
-    def test_failing_validation(self, not_a_geraetetyp):
-        with pytest.raises(TypeError) as excinfo:
+    def test_failing_validation(self, not_a_geraetetyp: Any) -> None:
+        with pytest.raises(ValidationError) as excinfo:
             _ = Geraeteeigenschaften(geraetemerkmal=Geraetemerkmal.GAS_G1000, geraetetyp=not_a_geraetetyp)
 
-        assert "'geraetetyp' must be " in str(excinfo.value)
+        assert "1 validation error" in str(excinfo.value)
+        assert "value is not a valid enumeration member" in str(excinfo.value)
