@@ -1,6 +1,6 @@
 import json
 
-from bo4e.bo.marktteilnehmer import Marktteilnehmer, MarktteilnehmerSchema
+from bo4e.bo.marktteilnehmer import Marktteilnehmer
 from bo4e.com.adresse import Adresse
 from bo4e.enum.botyp import BoTyp
 from bo4e.enum.geschaeftspartnerrolle import Geschaeftspartnerrolle
@@ -26,22 +26,20 @@ example_marktteilnehmer = Marktteilnehmer(
 
 
 class TestMarktteilnehmer:
-    def test_serialization(self):
+    def test_serialization(self) -> None:
         mt = example_marktteilnehmer
 
         assert mt.versionstruktur == "2", "versionstruktur was not automatically set"
         assert mt.bo_typ == BoTyp.MARKTTEILNEHMER, "boTyp was not automatically set"
 
-        schema = MarktteilnehmerSchema()
-
-        json_string = schema.dumps(mt, ensure_ascii=False)
+        json_string = mt.json(by_alias=True, ensure_ascii=False)
         json_dict = json.loads(json_string)
 
         # Test camelcase
         assert "boTyp" in json_dict
         assert "marktrolle" in json_dict
 
-        deserialized_mt: Marktteilnehmer = schema.loads(json_string)
+        deserialized_mt: Marktteilnehmer = Marktteilnehmer.parse_raw(json_string)
 
         assert mt.marktrolle is deserialized_mt.marktrolle
         # Test snakecase
