@@ -1,6 +1,7 @@
 import pytest  # type:ignore[import]
+from pydantic import ValidationError
 
-from bo4e.bo.preisblatt import Preisblatt, PreisblattSchema
+from bo4e.bo.preisblatt import Preisblatt
 from bo4e.enum.preisstatus import Preisstatus
 from bo4e.enum.sparte import Sparte
 from tests.serialization_helper import assert_serialization_roundtrip  # type:ignore[import]
@@ -25,13 +26,13 @@ class TestPreisblatt:
             ),
         ],
     )
-    def test_serialization_roundtrip(self, preisblatt: Preisblatt):
+    def test_serialization_roundtrip(self, preisblatt: Preisblatt) -> None:
         """
         Test de-/serialisation
         """
-        assert_serialization_roundtrip(preisblatt, PreisblattSchema())
+        assert_serialization_roundtrip(preisblatt)
 
-    def test_missing_required_attribute(self):
-        with pytest.raises(TypeError) as excinfo:
-            _ = Preisblatt()
-        assert "missing 5 required" in str(excinfo.value)
+    def test_missing_required_attribute(self) -> None:
+        with pytest.raises(ValidationError) as excinfo:
+            _ = Preisblatt()  # type: ignore[call-arg]
+        assert "5 validation errors" in str(excinfo.value)
