@@ -1,8 +1,10 @@
 from decimal import Decimal
+from typing import Any, Dict
 
 import pytest  # type:ignore[import]
+from pydantic import ValidationError
 
-from bo4e.com.preisstaffel import Preisstaffel, PreisstaffelSchema
+from bo4e.com.preisstaffel import Preisstaffel
 from tests.serialization_helper import assert_serialization_roundtrip  # type:ignore[import]
 from tests.test_sigmoidparameter import example_sigmoidparameter  # type:ignore[import]
 
@@ -23,36 +25,36 @@ class TestPreisstaffel:
                     sigmoidparameter=example_sigmoidparameter,
                 ),
                 {
-                    "einheitspreis": "40",
-                    "sigmoidparameter": {"A": "1", "B": "2", "C": "3", "D": "4"},
-                    "staffelgrenzeVon": "12.5",
-                    "staffelgrenzeBis": "25",
+                    "einheitspreis": Decimal("40"),
+                    "sigmoidparameter": {"A": Decimal("1"), "B": Decimal("2"), "C": Decimal("3"), "D": Decimal("4")},
+                    "staffelgrenzeVon": Decimal("12.5"),
+                    "staffelgrenzeBis": Decimal("25"),
                 },
                 id="all attributes",
             ),
             pytest.param(
                 example_preisstaffel,
                 {
-                    "einheitspreis": "40",
-                    "staffelgrenzeVon": "12.5",
-                    "staffelgrenzeBis": "25",
+                    "einheitspreis": Decimal("40"),
+                    "staffelgrenzeVon": Decimal("12.5"),
+                    "staffelgrenzeBis": Decimal("25"),
                     "sigmoidparameter": None,
                 },
                 id="only required params",
             ),
         ],
     )
-    def test_serialization_roundtrip(self, preisstaffel: Preisstaffel, expected_json_dict: dict):
+    def test_serialization_roundtrip(self, preisstaffel: Preisstaffel, expected_json_dict: Dict[str, Any]) -> None:
         """
         Test de-/serialisation of Preisstaffel.
         """
-        assert_serialization_roundtrip(preisstaffel, PreisstaffelSchema(), expected_json_dict)
+        assert_serialization_roundtrip(preisstaffel, expected_json_dict)
 
-    def test_missing_required_attribute(self):
-        with pytest.raises(TypeError) as excinfo:
-            _ = Preisstaffel()
+    def test_missing_required_attribute(self) -> None:
+        with pytest.raises(ValidationError) as excinfo:
+            _ = Preisstaffel()  # type: ignore[call-arg]
 
-        assert "missing 3 required" in str(excinfo.value)
+        assert "3 validation errors" in str(excinfo.value)
 
     @pytest.mark.parametrize(
         "not_a_sigmoid_parameter",
@@ -61,8 +63,8 @@ class TestPreisstaffel:
             pytest.param("foo"),  # not a sigmoid parameter instance
         ],
     )
-    def test_failing_validation(self, not_a_sigmoid_parameter):
-        with pytest.raises(TypeError) as excinfo:
+    def test_failing_validation(self, not_a_sigmoid_parameter: Any) -> None:
+        with pytest.raises(ValidationError) as excinfo:
             _ = Preisstaffel(
                 einheitspreis=Decimal(40.0),
                 staffelgrenze_von=Decimal(12.5),
@@ -70,4 +72,5 @@ class TestPreisstaffel:
                 sigmoidparameter=not_a_sigmoid_parameter,
             )
 
-        assert "'sigmoidparameter' must be " in str(excinfo.value)
+        assert "1 validation error" in str(excinfo.value)
+        assert "sigmoidparameter" in str(excinfo.value)
