@@ -1,6 +1,7 @@
 import pytest  # type:ignore[import]
+from pydantic import ValidationError
 
-from bo4e.bo.region import Region, RegionSchema
+from bo4e.bo.region import Region
 from tests.serialization_helper import assert_serialization_roundtrip  # type:ignore[import]
 from tests.test_regionskriterium import example_regionskriterium  # type:ignore[import]
 
@@ -22,21 +23,22 @@ class TestRegion:
             ),
         ],
     )
-    def test_serialization_roundtrip(self, region: Region):
-        assert_serialization_roundtrip(region, RegionSchema())
+    def test_serialization_roundtrip(self, region: Region) -> None:
+        assert_serialization_roundtrip(region)
 
-    def test_missing_required_attribute(self):
-        with pytest.raises(TypeError) as excinfo:
-            _ = Region()
+    def test_missing_required_attribute(self) -> None:
+        with pytest.raises(ValidationError) as excinfo:
+            _ = Region()  # type: ignore[call-arg]
 
-        assert "missing 2 required" in str(excinfo.value)
+        assert "2 validation errors" in str(excinfo.value)
 
-    def test_region_positiv_liste_required_and_negativ_liste_not_required(self):
-        with pytest.raises(ValueError) as excinfo:
+    def test_region_positiv_liste_required_and_negativ_liste_not_required(self) -> None:
+        with pytest.raises(ValidationError) as excinfo:
             _ = Region(
                 bezeichnung="Bikini Bottom",
                 positiv_liste=[],
                 negativ_liste=[],
             )
 
-        assert "List positiv_liste must not be empty." in str(excinfo.value)
+        assert "1 validation error" in str(excinfo.value)
+        assert "ensure this value has at least 1 item" in str(excinfo.value)
