@@ -1,8 +1,10 @@
 from decimal import Decimal
+from typing import Any, Dict
 
 import pytest  # type:ignore[import]
+from pydantic import ValidationError
 
-from bo4e.com.sigmoidparameter import Sigmoidparameter, SigmoidparameterSchema
+from bo4e.com.sigmoidparameter import Sigmoidparameter
 from tests.serialization_helper import assert_serialization_roundtrip  # type:ignore[import]
 
 # this sigmoid parameter can be imported by other tests
@@ -20,22 +22,22 @@ class TestSigmoidparameter:
         [
             pytest.param(
                 example_sigmoidparameter,
-                {"A": "1", "B": "2", "C": "3", "D": "4"},
+                {"A": Decimal("1"), "B": Decimal("2"), "C": Decimal("3"), "D": Decimal("4")},
             ),
         ],
     )
     def test_sigmoidparameter_serialization_roundtrip(
-        self, sigmoidparameter: Sigmoidparameter, expected_json_dict: dict
-    ):
+        self, sigmoidparameter: Sigmoidparameter, expected_json_dict: Dict[str, Any]
+    ) -> None:
         """
         Test de-/serialisation of Sigmoidparameter with minimal attributes.
         """
-        assert_serialization_roundtrip(sigmoidparameter, SigmoidparameterSchema(), expected_json_dict)
+        assert_serialization_roundtrip(sigmoidparameter, expected_json_dict)
 
-    def test_sigmoidparameter_missing_required_attribute(self):
-        with pytest.raises(TypeError) as excinfo:
-            _ = Sigmoidparameter()
-        assert "missing 4 required" in str(excinfo.value)
+    def test_sigmoidparameter_missing_required_attribute(self) -> None:
+        with pytest.raises(ValidationError) as excinfo:
+            _ = Sigmoidparameter()  # type: ignore[call-arg]
+        assert "4 validation errors" in str(excinfo.value)
 
     @pytest.mark.parametrize(
         "sigmoidparameter, leistung, expected_lp",
@@ -52,5 +54,5 @@ class TestSigmoidparameter:
             ),
         ],
     )
-    def test_lp_calculation(self, sigmoidparameter: Sigmoidparameter, leistung: Decimal, expected_lp: Decimal):
+    def test_lp_calculation(self, sigmoidparameter: Sigmoidparameter, leistung: Decimal, expected_lp: Decimal) -> None:
         assert sigmoidparameter.calculate(leistung) == expected_lp
