@@ -1,7 +1,10 @@
+from typing import Any, Dict, List
+
 import pytest  # type:ignore[import]
+from pydantic import ValidationError
 
 from bo4e.com.marktgebietinfo import MarktgebietInfo
-from bo4e.com.standorteigenschaftengas import StandorteigenschaftenGas, StandorteigenschaftenGasSchema
+from bo4e.com.standorteigenschaftengas import StandorteigenschaftenGas
 from tests.serialization_helper import assert_serialization_roundtrip  # type:ignore[import]
 
 example_standorteigenschaften_gas = StandorteigenschaftenGas(
@@ -24,31 +27,33 @@ class TestStandorteigenschaftenGas:
         ],
     )
     def test_standorteigenschaftengas_serialization_roundtrip(
-        self, standorteigenschaftengas: StandorteigenschaftenGas, expected_json_dict: dict
-    ):
-        assert_serialization_roundtrip(standorteigenschaftengas, StandorteigenschaftenGasSchema(), expected_json_dict)
+        self, standorteigenschaftengas: StandorteigenschaftenGas, expected_json_dict: Dict[str, Any]
+    ) -> None:
+        assert_serialization_roundtrip(standorteigenschaftengas, expected_json_dict)
 
-    def test_standorteigenschaftengas_missing_required_attributes(self):
-        with pytest.raises(TypeError) as excinfo:
-            _ = StandorteigenschaftenGas()
+    def test_standorteigenschaftengas_missing_required_attributes(self) -> None:
+        with pytest.raises(ValidationError) as excinfo:
+            _ = StandorteigenschaftenGas()  # type: ignore[call-arg]
 
-        assert "missing 2 required" in str(excinfo.value)
+        assert "2 validation errors" in str(excinfo.value)
 
     @pytest.mark.parametrize(
         "wrong_netzkontonummern, expected_error_message",
         [
             pytest.param(
                 [],
-                "netzkontonummern must not be empty.",
+                "ensure this value has at least 1 item",
             ),
             pytest.param(
                 ["1", "2", "3"],
-                "Maximum number of netzkontonummern is 2.",
+                "ensure this value has at most 2 items",
             ),
         ],
     )
-    def test_standorteigenschaftengas_list_lenght_validation(self, wrong_netzkontonummern, expected_error_message):
-        with pytest.raises(ValueError) as excinfo:
+    def test_standorteigenschaftengas_list_lenght_validation(
+        self, wrong_netzkontonummern: List[str], expected_error_message: str
+    ) -> None:
+        with pytest.raises(ValidationError) as excinfo:
             _ = StandorteigenschaftenGas(
                 netzkontonummern=wrong_netzkontonummern,
                 marktgebiete=[MarktgebietInfo(marktgebiet="Gaspool", marktgebietcode="37Z701133MH0000B")],
