@@ -1,6 +1,9 @@
-import pytest  # type:ignore[import]
+from typing import Any, Dict
 
-from bo4e.com.standorteigenschaftenstrom import StandorteigenschaftenStrom, StandorteigenschaftenStromSchema
+import pytest  # type:ignore[import]
+from pydantic import ValidationError
+
+from bo4e.com.standorteigenschaftenstrom import StandorteigenschaftenStrom
 from tests.serialization_helper import assert_serialization_roundtrip  # type:ignore[import]
 
 example_standorteigenschaften_strom = StandorteigenschaftenStrom(
@@ -25,14 +28,12 @@ class TestStandorteigenschaftenStrom:
         ],
     )
     def test_serialization_roundtrip(
-        self, standorteigenschaften_strom: StandorteigenschaftenStrom, expected_json_dict: dict
-    ):
-        assert_serialization_roundtrip(
-            standorteigenschaften_strom, StandorteigenschaftenStromSchema(), expected_json_dict
-        )
+        self, standorteigenschaften_strom: StandorteigenschaftenStrom, expected_json_dict: Dict[str, Any]
+    ) -> None:
+        assert_serialization_roundtrip(standorteigenschaften_strom, expected_json_dict)
 
-    def test_missing_required_attributes(self):
-        with pytest.raises(TypeError) as excinfo:
-            _ = StandorteigenschaftenStrom()
+    def test_missing_required_attributes(self) -> None:
+        with pytest.raises(ValidationError) as excinfo:
+            _ = StandorteigenschaftenStrom()  # type: ignore[call-arg]
 
-        assert "missing 3 required" in str(excinfo.value)
+        assert "3 validation errors" in str(excinfo.value)
