@@ -1,8 +1,9 @@
 from decimal import Decimal
 
 import pytest  # type:ignore[import]
+from pydantic import ValidationError
 
-from bo4e.com.tarifpreis import Tarifpreis, TarifpreisSchema
+from bo4e.com.tarifpreis import Tarifpreis
 from bo4e.enum.mengeneinheit import Mengeneinheit
 from bo4e.enum.preisstatus import Preisstatus
 from bo4e.enum.preistyp import Preistyp
@@ -17,19 +18,18 @@ example_tarifpreis = Tarifpreis(
 
 
 class TestTarifpreis:
-    def test_tarifpreis_only_required(self):
+    def test_tarifpreis_only_required(self) -> None:
         """
         Test de-/serialisation of Tarifpreis (only has required attributes).
         """
         tarifpreis = example_tarifpreis
 
-        schema = TarifpreisSchema()
-        json_string = schema.dumps(tarifpreis, ensure_ascii=False)
+        json_string = tarifpreis.json(by_alias=True, ensure_ascii=False)
 
         assert "ARBEITSPREIS_HT" in json_string
         assert "null" in json_string
 
-        tarifpreis_deserialized = schema.loads(json_string)
+        tarifpreis_deserialized = Tarifpreis.parse_raw(json_string)
 
         assert isinstance(tarifpreis_deserialized.wert, Decimal)
         assert isinstance(tarifpreis_deserialized.einheit, Waehrungseinheit)
@@ -38,26 +38,31 @@ class TestTarifpreis:
         assert tarifpreis_deserialized.beschreibung is None
         assert tarifpreis == tarifpreis_deserialized
 
-    def test_wrong_datatype(self):
-        with pytest.raises(TypeError) as excinfo:
+    def test_wrong_datatype(self) -> None:
+        with pytest.raises(ValidationError) as excinfo:
             _ = Tarifpreis(
-                wert=3.50, einheit=Waehrungseinheit.EUR, bezugswert=Mengeneinheit.KWH, preistyp=Preistyp.ARBEITSPREIS_HT
+                wert="blubb",  # type: ignore[arg-type]
+                einheit=Waehrungseinheit.EUR,
+                bezugswert=Mengeneinheit.KWH,
+                preistyp=Preistyp.ARBEITSPREIS_HT,
             )
 
-        assert "'wert' must be <class 'decimal.Decimal'>" in str(excinfo.value)
+        assert "1 validation error" in str(excinfo.value)
+        assert "wert" in str(excinfo.value)
+        assert "value is not a valid decimal" in str(excinfo.value)
 
-    def test_missing_required_attribute(self):
-        with pytest.raises(TypeError) as excinfo:
-            _ = Tarifpreis(
+    def test_missing_required_attribute(self) -> None:
+        with pytest.raises(ValidationError) as excinfo:
+            _ = Tarifpreis(  # type: ignore[call-arg]
                 wert=Decimal(3.50),
                 einheit=Waehrungseinheit.EUR,
                 status=Preisstatus.ENDGUELTIG,
                 bezugswert=Mengeneinheit.KWH,
             )
 
-        assert "missing 1 required" in str(excinfo.value)
+        assert "1 validation error" in str(excinfo.value)
 
-    def test_optional_attribute(self):
+    def test_optional_attribute(self) -> None:
         tarifpreis = Tarifpreis(
             wert=Decimal(3.50),
             einheit=Waehrungseinheit.EUR,
@@ -67,12 +72,11 @@ class TestTarifpreis:
             beschreibung="Das ist ein HT Arbeitspreis",
         )
 
-        schema = TarifpreisSchema()
-        json_string = schema.dumps(tarifpreis, ensure_ascii=False)
+        json_string = tarifpreis.json(by_alias=True, ensure_ascii=False)
 
         assert "Das ist ein HT Arbeitspreis" in json_string
 
-        tarifpreis_deserialized = schema.loads(json_string)
+        tarifpreis_deserialized = Tarifpreis.parse_raw(json_string)
 
         assert isinstance(tarifpreis_deserialized.beschreibung, str)
         assert tarifpreis_deserialized.beschreibung == "Das ist ein HT Arbeitspreis"
