@@ -1,8 +1,9 @@
 from decimal import Decimal
 
 import pytest  # type:ignore[import]
+from pydantic import ValidationError
 
-from bo4e.com.tarifpreisstaffelproort import TarifpreisstaffelProOrt, TarifpreisstaffelProOrtSchema
+from bo4e.com.tarifpreisstaffelproort import TarifpreisstaffelProOrt
 from tests.serialization_helper import assert_serialization_roundtrip  # type:ignore[import]
 
 example_tarifpreisstaffelproort = TarifpreisstaffelProOrt(
@@ -24,14 +25,14 @@ class TestTarifpreisstaffelProOrt:
             ),
         ],
     )
-    def test_serialization_roundtrip(self, tarifpreisstaffelproort: TarifpreisstaffelProOrt):
+    def test_serialization_roundtrip(self, tarifpreisstaffelproort: TarifpreisstaffelProOrt) -> None:
         """
         Test de-/serialisation
         """
-        assert_serialization_roundtrip(tarifpreisstaffelproort, TarifpreisstaffelProOrtSchema())
+        assert_serialization_roundtrip(tarifpreisstaffelproort)
 
-    def test_missing_required_attribute(self):
-        with pytest.raises(TypeError) as excinfo:
-            _ = TarifpreisstaffelProOrt()
+    def test_missing_required_attribute(self) -> None:
+        with pytest.raises(ValidationError) as excinfo:
+            _ = TarifpreisstaffelProOrt()  # type: ignore[call-arg]
 
-        assert "missing 5 required" in str(excinfo.value)
+        assert "5 validation errors" in str(excinfo.value)
