@@ -2,8 +2,9 @@ from datetime import datetime, timezone
 from decimal import Decimal
 
 import pytest  # type:ignore[import]
+from pydantic import ValidationError
 
-from bo4e.com.zeitreihenwert import Zeitreihenwert, ZeitreihenwertSchema
+from bo4e.com.zeitreihenwert import Zeitreihenwert
 from bo4e.enum.messwertstatus import Messwertstatus
 from bo4e.enum.messwertstatuszusatz import Messwertstatuszusatz
 
@@ -15,22 +16,21 @@ example_zeitreihenwert = Zeitreihenwert(
 
 
 class TestZeitreihenwert:
-    def test_zeitreihenwert_only_required_attributes(self):
+    def test_zeitreihenwert_only_required_attributes(self) -> None:
         """
         Test de-/serialisation of Zeitreihenwert with minimal attributes.
         """
         zeitreihenwert = example_zeitreihenwert
 
-        schema = ZeitreihenwertSchema()
-        json_string = schema.dumps(zeitreihenwert, ensure_ascii=False)
+        json_string = zeitreihenwert.json(by_alias=True, ensure_ascii=False)
 
         assert "2001-03-15T00:00:00+00:00" in json_string
         assert "2007-11-27T00:00:00+00:00" in json_string
 
-        zeitreihenwert_deserialized: Zeitreihenwert = schema.loads(json_string)
+        zeitreihenwert_deserialized: Zeitreihenwert = Zeitreihenwert.parse_raw(json_string)
         assert zeitreihenwert_deserialized == zeitreihenwert
 
-    def test_zeitreihenwert_required_and_optional_attributes(self):
+    def test_zeitreihenwert_required_and_optional_attributes(self) -> None:
         """
         Test de-/serialisation of Zeitreihenwert with maximal attributes.
         """
@@ -42,8 +42,7 @@ class TestZeitreihenwert:
             statuszusatz=Messwertstatuszusatz.Z78_GERAETEWECHSEL,
         )
 
-        schema = ZeitreihenwertSchema()
-        json_string = schema.dumps(zeitreihenwert, ensure_ascii=False)
+        json_string = zeitreihenwert.json(by_alias=True, ensure_ascii=False)
 
         assert "2.5" in json_string
         assert "2001-03-15T00:00:00+00:00" in json_string
@@ -51,17 +50,17 @@ class TestZeitreihenwert:
         assert "ABGELESEN" in json_string
         assert "Z78_GERAETEWECHSEL" in json_string
 
-        zeitreihenwert_deserialized: Zeitreihenwert = schema.loads(json_string)
+        zeitreihenwert_deserialized: Zeitreihenwert = Zeitreihenwert.parse_raw(json_string)
         assert zeitreihenwert_deserialized == zeitreihenwert
 
-    def test_missing_required_attribute(self):
-        with pytest.raises(TypeError) as excinfo:
-            _ = Zeitreihenwert(datum_uhrzeit_von=datetime(2007, 11, 27, tzinfo=timezone.utc), wert=Decimal(1.5))
+    def test_missing_required_attribute(self) -> None:
+        with pytest.raises(ValidationError) as excinfo:
+            _ = Zeitreihenwert(datum_uhrzeit_von=datetime(2007, 11, 27, tzinfo=timezone.utc), wert=Decimal(1.5))  # type: ignore[call-arg]
 
-        assert "missing 1 required" in str(excinfo.value)
+        assert "1 validation error" in str(excinfo.value)
 
-    def test_von_later_than_bis(self):
-        with pytest.raises(ValueError) as excinfo:
+    def test_von_later_than_bis(self) -> None:
+        with pytest.raises(ValidationError) as excinfo:
             _ = Zeitreihenwert(
                 datum_uhrzeit_von=datetime(2007, 11, 27, tzinfo=timezone.utc),
                 datum_uhrzeit_bis=datetime(2006, 11, 27, tzinfo=timezone.utc),
